// @author Laura
// This module implements the com.ibm.mashups.enabler.runtime.skin.StyleFilter interface
// It is meant to be applied to a layout container
// Other modules should inherit from this and overwrite the _isAgree and _filterStyle functions to make any changes
// known to inherit : 	com.ibm.pb.layout.filters.ColumnContainerStyleFilter
//						com.ibm.pb.layout.filters.RowContainerStyleFilter
//						com.ibm.pb.layout.filters.FreeFormContainerStyleFilter

dojo.provide("com.ibm.pb.layout.filters.ContainerStyleFilter");
dojo.require("com.ibm.pb.layout.LayoutParser");
dojo.declare("com.ibm.pb.layout.filters.ContainerStyleFilter", [com.ibm.mashups.enabler.runtime.skin.StyleFilter], {

	widgetMaxHeight: 10000,	// widget maximum height in pixels
	widgetMaxWidth: 10000,	// widget maximum width in pixels
	widgetMinWidth: 100,	// widget minimum width in pixels
	widgetMinHeight: 80,	// widget minimum height in pixels
	containerMinWidth: 5, 	// container minimum width in a percentage
	
	onChangingStyle: function(layoutNode, oldStyle, newStyle, filterControl, filterChain) {
		// summary: set disagree if _isAgree returns false, then trigger the next filter
		// 			gets called as part of the filter chain triggered when checkStyle() is called on a runtime skin node
		var node = com.ibm.pb.layout.LayoutParser.findById(layoutNode.getID());
        if (!this._isAgree(layoutNode, node, oldStyle, newStyle)) {
			filterControl.setDisagree();   
        }
		this._filterStyle(layoutNode, node, oldStyle, newStyle);
		filterChain.doFilter(layoutNode, oldStyle, newStyle, filterControl);
    },
    
    onChangeStyle: function(layoutNode, oldStyle, newStyle, filterChain) {
		// summary: filter the new style and call the next filter if _isAgree returns true
		// 			gets called as part of the filter chain triggered when setStyle() is called on a modifiable runtime skin node
		var node = com.ibm.pb.layout.LayoutParser.findById(layoutNode.getID());
        if (this._isAgree(layoutNode, node, oldStyle, newStyle)) {
			this._filterStyle(layoutNode, node, oldStyle, newStyle);
            filterChain.doFilter(layoutNode, oldStyle, newStyle);
        }
    },
	
	_isContainer: function(layoutNode) {
		// summary: returns true if the given node is a layout container
		return (layoutNode instanceof com.ibm.mashups.enabler.layout.LayoutContainer);
	},
	
	_isControl: function(layoutNode) {
		// summary: returns true if the given node is a layout control
		return (layoutNode instanceof com.ibm.mashups.enabler.layout.LayoutControl);
	},
	
	_isAgree: function(layoutNode, node, oldStyle, newStyle) {
		// summary: return true if the new style is allowed, false otherwise
		return true;
	},
	
	_filterStyle: function(layoutNode, node, oldStyle, newStyle) {
		// summary: makes any needed changes to the newStyle object
	}
});
