dojo.provide("com.ibm.pb.widgets.ContentMenu");

dojo.require("dijit.Menu");
dojo.require("dijit.MenuItem");
dojo.require("dijit.PopupMenuItem");
dojo.require("dijit.MenuSeparator");
dojo.require("com.ibm.pb.logging.Loggable");

dojo.declare("com.ibm.pb.widgets.ContentMenu", [dijit.Menu, com.ibm.pb.logging.Loggable], {
	
	builderFactory: com.ibm.mashups.builder.model.Factory,
	
	contextMenuID: "",
	resourceType: "",
	resourceID: "",
	
	_setListener: null,
	internalRefresh:true,
	
	postCreate: function() {
		this.refreshContents();
		this.connect(this, "onSetChange", "refreshContents");
		this.connectKeyNavHandlers([dojo.keys.UP_ARROW], [dojo.keys.DOWN_ARROW]);
	},
	getSet: function() {
		var mname = "getSet", lgr = this.LOGGER;
		lgr.entering(mname, arguments);
		var contextMenu = this.builderFactory.getContextMenuModel();
		var data = contextMenu.getContextMenu(this.contextMenuID, this.resourceID, 
			this.resourceType, this.getSetContextParams());
		if(!this._setListener && this.internalRefresh) {
			this._setListener = contextMenu.registerListener(this.contextMenuID, this, "onSetChange");
		}
		lgr.exiting(mname, [data]);
		return data;
	},
	getSetContextParams: function() {
		return { context:this };
	},
	getInheritableParams: function(item) {
		return {
			contextMenuID: item.contextMenuID || this.contextMenuID,
			resourceType: item.resourceType || this.resourceType,
			resourceID: item.resourceId || this.resourceID,
			internalRefresh:this.internalRefresh
		};
	},
	destroy: function() {
		if(this._setListener) {
			this.builderFactory.getContextMenuModel().unregisterListener(this._setListener);
			delete this._setListener;
		}
		this.inherited(arguments);
	},
	getItemRep: function(item) {
		var menuItem = null;
		if(item.isSeparator) {
			menuItem = new dijit.MenuSeparator();
		}
		else if(item.contextMenuID) {
			var subCSMenu = this.createSubmenu(this.getInheritableParams(item));
			menuItem = new dijit.PopupMenuItem({
				label: item.title,
				iconClass: item.iconClass || "",
				popup: subCSMenu,
				disabled: !item.enabled,
				onClick: item.actionCallBackFunction,
				pageActionType: item.id
			});
		}
		else {
			if (item.checkedMenuItem){
				menuItem = new dijit.CheckedMenuItem({
					label: item.title,
					iconClass: item.iconClass || "",
					disabled: !item.enabled,
					onClick: item.actionCallBackFunction,
					checked: item.checked,
					pageActionType: item.id
				});
			}else {
				menuItem = new dijit.MenuItem({
					label: item.title,
					iconClass: item.iconClass || "",
					disabled: !item.enabled,
					onClick: item.actionCallBackFunction,
					pageActionType: item.id
				});
			}
		}
		if(item.itemClass) {
			dojo.addClass(menuItem.domNode, item.itemClass);
		}
		return menuItem;
	},
	onSetChange: function() {},
	createSubmenu: function(args) {
		var subCSMenu = new com.ibm.pb.widgets.ContentMenu(args);
		return subCSMenu;
	},
	initContents: function(resourceID) {
		var mname = "initContents", lgr = this.LOGGER;
		lgr.entering(mname, arguments);
		// clear the existing contents, and rebuild the menu contents
		this.resourceID = resourceID;
		this.clearContents();
		this.fillContents();
		lgr.exiting(mname, arguments);
	},
	clearContents: function() {
		this.destroyDescendants();
	},
	refreshContents: function() {
		if(this.resourceID) {
			this.initContents(this.resourceID);
		}
	},
	fillContents: function() {
		var mname = "fillContents", lgr = this.LOGGER;
		lgr.entering(mname, arguments);
		// get the contents of the menu from the data set, then rebuild the visual elements of 
		// the menu using the returned data
		var data = this.getSet();
		dojo.forEach(data, function(item){
			var menuItem = this.getItemRep(item);
			lgr.trace(mname, "Adding menu item ${0} to menu ${1} backed by item ${2}", [menuItem, this, item]);
			this.addChild(menuItem);
		}, this);
		lgr.exiting(mname, [data]);
	}
});