/* Copyright IBM Corp. 2013  All Rights Reserved.                    */
dojo.provide("com.ibm.mashups.enabler.logging.LogLevel" ); 

/**
* The LogLevel class defines a set of standard logging levels that can be used to control logging output. 
* The logging levels are internally ordered. Enabling logging at a given level also enables logging at all higher levels.
*
* Clients should normally use the predefined Level constants such as <code>com.ibm.mashups.enabler.logging.LogLevel.SEVERE</code>.
*
* The levels in descending order are:
* <ul>
* <li>SEVERE (highest value)</li>
* <li>WARNING</li>
* <li>INFO</li>
* <li>TRACE (lowest value)</li>
* </ul>
*
* @ibm-api
* @ibm-module Base2
*/
dojo.declare("com.ibm.mashups.enabler.logging.LogLevel", null,
{
	/**
	* TRACE is a message level providing tracing information.<br/><br/>
	* TRACE is intended for relatively detailed tracing. The exact meaning of the this levels will vary 
	* between subsystems. 
	* In general the TRACE level should be used for information that will be broadly interesting to developers 
	* who do not have a specialized interest in the specific subsystem.<br/><br/>
	* TRACE messages might include things like minor (recoverable) failures. Issues indicating potential 
	* performance problems are also worth logging as FINE. This level is initialized to <code>500</code>.
	* @type {int}
	*/
	TRACE:   500,
	/**
	* INFO is a message level for informational messages.<br/><br/>
	* Typically INFO messages will be written to the console or its equivalent (like the system messages widget).
	* So the INFO level should only be used for reasonably significant messages that will make sense 
	* to end users and system admins. This level is initialized to <code>800</code>.
	* @type {int}
	*/
	INFO:    800,
	/**
	* WARNING is a message level indicating a potential problem.<br/><br/>
	* In general WARNING messages should describe events that will be of interest to end users or system 
	* managers, or which indicate potential problems. This level is initialized to <code>900</code>. 
	* @type {int}
	*/
	WARNING: 900,
	/**
	* SEVERE is a message level indicating a serious failure.<br/><br/>
	* In general SEVERE messages should describe events that are of considerable importance and which 
	* will prevent normal program execution. They should be reasonably intelligible to end users and to 
	* system administrators. This level is initialized to <code>1000</code>. 
	* @type {int}
	*/
	SEVERE:  1000
});

// instance of the internal log level class for convinient accessing of the LogLevels.
com.ibm.mashups.enabler.logging.LogLevel = new com.ibm.mashups.enabler.logging.LogLevel();
